"""add response count field

Revision ID: 2a4397511296
Revises: 11ec5eb390f4
Create Date: 2015-03-12 17:15:03.910473

"""

# revision identifiers, used by Alembic.
revision = '2a4397511296'
down_revision = '11ec5eb390f4'
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa


def upgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.add_column('question_options', sa.Column('responses_count', sa.Integer(), nullable=True))
    ### end Alembic commands ###


def downgrade():
    ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('question_options', 'responses_count')
    ### end Alembic commands ###
